<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he_IL">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About</source>
        <translation type="obsolete">אודות</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>כותבים</translation>
    </message>
    <message>
        <source>License</source>
        <translation>רישיון</translation>
    </message>
    <message>
        <source>Lightweight WebKit-based web browser</source>
        <translation>דפדפן רשת קליל מבוסס WebKit</translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2008 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body dir=&quot;RTL&quot; style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;כל הזכויות שמורות © 2007-2008 Benjamin C. Meyer &amp;lt;‏&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>סגור</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AcceptLanguage</name>
    <message>
        <source>Languages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Languages: in order of preference:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>הוסף סימנית</translation>
    </message>
    <message>
        <source>Type a name for the bookmark, and choose where to keep it.</source>
        <translation>כתוב שם עבור הסימנית ובחר היכן לשמור אותה.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished">כותרת</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation type="unfinished">הוסף תיקייה</translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <source>Open</source>
        <translation>פתח</translation>
    </message>
    <message>
        <source>Open in New Tab</source>
        <translation>פתח בכרטיסייה חדשה</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>מחק</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>תיקייה חדשה</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>סימניות</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>ה&amp;סר</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>הוסף תיקייה</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Error when loading bookmarks on line %1, column %2:
%3</source>
        <translation>ארעה שגיאה בעת טעינה של סימניות בשורה %1, עמודה %2:
%3</translation>
    </message>
    <message>
        <source>Toolbar Bookmarks</source>
        <translation>סרגל כלים של סימניות</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>תפריט</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>פתח קובץ</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml)</source>
        <translation type="obsolete">XBEL (*.xbel *.xml)</translation>
    </message>
    <message>
        <source>Imported %1</source>
        <translation>הייבוא של %1 הסתיים</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>שמור קובץ</translation>
    </message>
    <message>
        <source>%1 Bookmarks.xbel</source>
        <translation>%1 Bookmarks.xbel</translation>
    </message>
    <message>
        <source>Export error</source>
        <translation>שגיאת ייצוא</translation>
    </message>
    <message>
        <source>error saving bookmarks</source>
        <translation>ארעה שגיאה בעת יצוא הסימניות</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>הסר סימנייה</translation>
    </message>
    <message>
        <source>Insert Bookmark</source>
        <translation>ייבוא של סימניות</translation>
    </message>
    <message>
        <source>Name Change</source>
        <translation type="obsolete">שנה שם</translation>
    </message>
    <message>
        <source>Address Change</source>
        <translation type="obsolete">שנה כתובת</translation>
    </message>
    <message>
        <source>Bookmarks Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Change</source>
        <comment>Undo bookmark title change</comment>
        <translation type="unfinished">שנה שם</translation>
    </message>
    <message>
        <source>Address Change</source>
        <comment>Undo bookmark url change</comment>
        <translation type="unfinished">שנה כתובת</translation>
    </message>
    <message>
        <source>XBEL bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HTML Netscape bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>htmlToXBel tool required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error when loading HTML bookmarks: %1
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksMenu</name>
    <message>
        <source>Open in Tabs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksModel</name>
    <message>
        <source>Title</source>
        <translation>כותרת</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>כתובת</translation>
    </message>
</context>
<context>
    <name>BookmarksToolBar</name>
    <message>
        <source>Bookmark</source>
        <translation type="obsolete">סימניות</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished">פתח</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation type="unfinished">פתח ב&amp;כרטיסייה חדשה</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation type="unfinished">הוסף סימנייה...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="unfinished">סימניות</translation>
    </message>
</context>
<context>
    <name>BrowserApplication</name>
    <message>
        <source> (Change: %1 %2)</source>
        <translation type="obsolete">(שינוי %1 %2)</translation>
    </message>
    <message>
        <source>There are %1 windows and %2 tabs open
Do you want to quit anyway?</source>
        <translation>ישנם %1 חלונות ו־%2 כרטיסיות פתוחות.
האם לצאת בכל זאת?</translation>
    </message>
    <message>
        <source>Restore failed</source>
        <translation>השחזרור נכשל</translation>
    </message>
    <message>
        <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
        <translation>אין אפשרות לשחזר את ההפעלה השמורה כיוון ש־Arora קרס בזמן השיחזור של ההפעלה.</translation>
    </message>
</context>
<context>
    <name>BrowserMainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;קובץ</translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation>&amp;חלון חדש</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation>&amp;פתח קובץ...</translation>
    </message>
    <message>
        <source>Open &amp;Location...</source>
        <translation>&amp;פתח מיקום...</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>שמור &amp;בשם...</translation>
    </message>
    <message>
        <source>&amp;Import Bookmarks...</source>
        <translation>יי&amp;בא סימניות...</translation>
    </message>
    <message>
        <source>&amp;Export Bookmarks...</source>
        <translation>יי&amp;צא סימניות...</translation>
    </message>
    <message>
        <source>P&amp;rint Preview...</source>
        <translation>ת&amp;צוגת הדפסה...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;הדפס...</translation>
    </message>
    <message>
        <source>Private &amp;Browsing...</source>
        <translation>&amp;גלישה מאובטחת...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;יציאה</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>ע&amp;ריכה</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;בטל</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;שחזר</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;גזור</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;העתק</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;הדבק</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;חפש</translation>
    </message>
    <message>
        <source>Find Nex&amp;t</source>
        <translation>חפש ה&amp;בא</translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation>חפש &amp;קודם</translation>
    </message>
    <message>
        <source>Prefere&amp;nces...</source>
        <translation>&amp;הגדרות...</translation>
    </message>
    <message>
        <source>Ctrl+,</source>
        <translation>Ctrl+, ‎</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;תצוגה</translation>
    </message>
    <message>
        <source>Show Menu Bar</source>
        <translation>הצג תפריט</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Shift+Ctrl+B</source>
        <translation>Shift+Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation>Ctrl+/</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;עצור</translation>
    </message>
    <message>
        <source>&amp;Reload Page</source>
        <translation>&amp;רענן עמוד</translation>
    </message>
    <message>
        <source>Make Text &amp;Bigger</source>
        <translation type="obsolete">&amp;הגדל גופן</translation>
    </message>
    <message>
        <source>Make Text &amp;Normal</source>
        <translation type="obsolete">גופן &amp;רגיל</translation>
    </message>
    <message>
        <source>Make Text &amp;Smaller</source>
        <translation type="obsolete">ה&amp;קטן גופן</translation>
    </message>
    <message>
        <source>Page S&amp;ource</source>
        <translation>&amp;הצג מקור המסמך</translation>
    </message>
    <message>
        <source>Ctrl+Alt+U</source>
        <translation>Ctrl+Alt+U</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;מסך מלא</translation>
    </message>
    <message>
        <source>Hi&amp;story</source>
        <translation>&amp;היסטוריה</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>חזור</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>הבא</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>עמוד הבית</translation>
    </message>
    <message>
        <source>Restore Last Session</source>
        <translation>שחזר הפעלה קודמת</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;סימניות</translation>
    </message>
    <message>
        <source>Manage Bookmarks...</source>
        <translation type="obsolete">ניהול סימניות...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>הוסף סימנייה...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;חלון</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;כלים</translation>
    </message>
    <message>
        <source>Web &amp;Search</source>
        <translation>חיפוש &amp;ברשת</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <comment>Web Search</comment>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>&amp;Clear Private Data</source>
        <translation>&amp;מחק מידע אישי</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <comment>Clear Private Data</comment>
        <translation>Ctrl+Shift+Delete</translation>
    </message>
    <message>
        <source>Enable Web &amp;Inspector</source>
        <translation>&amp;אפשר סורק רשת</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;אודות Qt</translation>
    </message>
    <message>
        <source>About &amp;Arora</source>
        <translation type="obsolete">א&amp;ודות Arora</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>ניווט</translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>הצג שורת מצב</translation>
    </message>
    <message>
        <source>Hide Status Bar</source>
        <translation>הסתר שורת מצב</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>הצג סרגל כלים</translation>
    </message>
    <message>
        <source>Hide Toolbar</source>
        <translation>הסתר סרגל כלים</translation>
    </message>
    <message>
        <source>Show Bookmarks Bar</source>
        <translation>הצג סרגל סימניות</translation>
    </message>
    <message>
        <source>Hide Bookmarks Bar</source>
        <translation>הסתר סרגל סימניות</translation>
    </message>
    <message>
        <source>Arora</source>
        <translation type="obsolete">Arora</translation>
    </message>
    <message>
        <source>%1 - Arora</source>
        <comment>Page title and Browser name</comment>
        <translation>‏Arora‏ - %1</translation>
    </message>
    <message>
        <source>Open Web Resource</source>
        <translation>פתח משאב רשת</translation>
    </message>
    <message>
        <source>Web Resources (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</source>
        <translation>משאב רשת (*.html *.htm *.svg *.png *.gif *.svgz);; כל הקבצים (*.*)</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>הדפס מסמך</translation>
    </message>
    <message>
        <source>Are you sure you want to turn on private browsing?</source>
        <translation>האם באמת ברצונך להפעיל גלישה מאובטחת?</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not addded to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;span dir=&quot;rtl&quot;&gt;&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;כאשר מופעלת גלישה מאובטחת כמה פעולות הקשורות לפרטיות שלך לא יופעלו:&lt;ul dir=&quot;rtl&quot;&gt;&lt;li&gt; דפים לא נוספים להסטוריית הגלישה.&lt;/li&gt;&lt;li&gt; פריטים נמחקים באופן אוטומטי מרשימת ההורדות.&lt;/li&gt;&lt;li&gt; עוגיות חדשות לא נשמרות ואין אפשרות לגשת לעוגיות ישנות.&lt;/li&gt;&lt;li&gt; סמלים של אתרים לא נשמרים וההפעלה לא תישמר.&lt;/li&gt;&lt;li&gt; חיפושים לא מתווספים לתפריט המוקפץ של היסטוריית החיפוש.&lt;/li&gt;&lt;/ul&gt;עד שתסגור את החלון, באפשרותך ללחוץ על כפתורי הניווט &quot;קדימה&quot; ו־&quot;אחורה&quot; לחזרה לעמודים שביקרת בהם.
&lt;/span&gt;</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation>האם אתה באמת ברצונך לסגור את החלון? ישנן %1 כרטיסיות פתוחות</translation>
    </message>
    <message>
        <source>Page Source of %1</source>
        <translation type="obsolete">קוד המקור של %1</translation>
    </message>
    <message>
        <source>Web Inspector</source>
        <translation>סורק רשת</translation>
    </message>
    <message>
        <source>The web inspector will only work correctly for pages that were loaded after enabling.
Do you want to reload all pages?</source>
        <translation>סורק הרשת יעבוד נכון רק עבור דפים שנטענו אחרי ההפעלה שלו.
האם ברצונך לרענן את כל הדפים?</translation>
    </message>
    <message>
        <source>Stop loading the current page</source>
        <translation>עצור את טעינת הדף הנוכחי</translation>
    </message>
    <message>
        <source>Reload the current page</source>
        <translation>טען מחדש את הדף הנוכחי</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>הורדות</translation>
    </message>
    <message>
        <source>Alt+Ctrl+L</source>
        <comment>Download Manager</comment>
        <translation type="obsolete">Alt+Ctrl+L</translation>
    </message>
    <message>
        <source>Switch application language </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Text Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show All Bookmarks...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About &amp;%1</source>
        <comment>About Browser</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <comment>Download Manager</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;li&gt; Network cache is disabled.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>מחק</translation>
    </message>
</context>
<context>
    <name>ClearPrivateData</name>
    <message>
        <source>Clear Private Data</source>
        <translation>מחק מידע פרטי</translation>
    </message>
    <message>
        <source>Clear the following items:</source>
        <translation>מחק את הפרטים הבאים:</translation>
    </message>
    <message>
        <source>&amp;Browsing History</source>
        <translation>&amp;היסטורית גלישה</translation>
    </message>
    <message>
        <source>&amp;Download History</source>
        <translation>הסטורית הו&amp;רדה</translation>
    </message>
    <message>
        <source>&amp;Search History</source>
        <translation>הסיטוריית &amp;חיפוש</translation>
    </message>
    <message>
        <source>&amp;Cookies</source>
        <translation>&amp;עוגיות</translation>
    </message>
    <message>
        <source>C&amp;ached Web Pages</source>
        <translation>דפי אינטרנט ב&amp;מטמון</translation>
    </message>
    <message>
        <source>Website &amp;Icons</source>
        <translation>סמלים של &amp;אתרים</translation>
    </message>
    <message>
        <source>Clear &amp;Private Data</source>
        <translation>אפס מידע &amp;אישי</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;ביטול</translation>
    </message>
</context>
<context>
    <name>ClickToFlash</name>
    <message>
        <source>Load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add %1 to Whitelist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from Whitelist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load Flash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClickToFlashSettings</name>
    <message>
        <source>Whitelist sites</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookieExceptionsModel</name>
    <message>
        <source>Website</source>
        <translation>אתר אינטרנט</translation>
    </message>
    <message>
        <source>Rule</source>
        <translation>חוק</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>אפשר</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>חסום</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>אפשר להפעלה נוכחית</translation>
    </message>
</context>
<context>
    <name>CookieModel</name>
    <message>
        <source>Website</source>
        <translation>כתובת</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>נתיב</translation>
    </message>
    <message>
        <source>Secure</source>
        <translation>מאובטח</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>תאריך תפוגה</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>תוכן</translation>
    </message>
    <message>
        <source>true</source>
        <translation>true</translation>
    </message>
    <message>
        <source>false</source>
        <translation>false</translation>
    </message>
    <message>
        <source>Session cookie</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookiesDialog</name>
    <message>
        <source>Cookies</source>
        <translation>עוגיות</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;מחק</translation>
    </message>
    <message>
        <source>Remove &amp;All Cookies</source>
        <translation>מחק את &amp;כל העוגיות</translation>
    </message>
    <message>
        <source>Add &amp;Rule</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookiesExceptionsDialog</name>
    <message>
        <source>Cookie Exceptions</source>
        <translation>עוגיות יוצאות מן הכלל</translation>
    </message>
    <message>
        <source>New Exception</source>
        <translation>יוצא מן הכלל חדש</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>מתחם:</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>בלוק</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>אפשר להפעלה הנוכחית</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>אפשר</translation>
    </message>
    <message>
        <source>Exceptions</source>
        <translation>יוצרים מן הכלל</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>ה&amp;סר</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>&amp;הסר הכל</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>הורדות</translation>
    </message>
    <message>
        <source>Clean up</source>
        <translation>נקה</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 פריטים</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;אישור</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">ממקום</translation>
    </message>
    <message>
        <source>Ico</source>
        <translation>Ico</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>שם קובץ</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>נסה שוב</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>עצור</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>פתח</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>שמור קובץ</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>ההודעה הופסקה: %1</translation>
    </message>
    <message>
        <source>Error opening output file: %1</source>
        <translation>ארעה שגיאה בעת פתיחת קובץ הפלט: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>ארעה שגיאה בעת השמירה: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>ארעה שגיאות רשת: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation type="obsolete">שניות</translation>
    </message>
    <message numerus="yes">
        <source>- %n minutes remaining</source>
        <translation type="obsolete">
            <numerusform>נשארו עוד %n שניות</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>- %n seconds remaining</source>
        <translation type="obsolete">
            <numerusform>נשארו עוד %n דקות</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation type="obsolete">%1 מתוך %2 (%3 קס&quot;ש) %2</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 מתוך %2 - נעצר</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation type="obsolete">בתים</translation>
    </message>
    <message>
        <source>kB</source>
        <translation type="obsolete">ק&quot;ב</translation>
    </message>
    <message>
        <source>MB</source>
        <translation type="obsolete">מ&quot;ב</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) - %4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download directory (%1) couldn&apos;t be created.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>הורדה אחת</numerusform>
            <numerusform>%n הורדות</numerusform>
        </translation>
    </message>
    <message>
        <source>There are %1 downloads in progress
Do you want to quit anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n minutes remaining</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n seconds remaining</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation type="unfinished">בתים</translation>
    </message>
    <message>
        <source>kB</source>
        <translation type="unfinished">ק&quot;ב</translation>
    </message>
    <message>
        <source>MB</source>
        <translation type="unfinished">מ&quot;ב</translation>
    </message>
    <message>
        <source>GB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileAccessReply</name>
    <message>
        <source>No Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening: %1: No such file or directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contents of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>Open</source>
        <translation>פתח</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>העתק</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>מחק</translation>
    </message>
    <message>
        <source>History</source>
        <translation>היסטוריה</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>ה&amp;סר</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>&amp;הסר הכל</translation>
    </message>
</context>
<context>
    <name>HistoryMenu</name>
    <message>
        <source>Show All History</source>
        <translation>הצג את כל ההסטוריה</translation>
    </message>
    <message>
        <source>Clear History...</source>
        <translation>מחק את ההיסטוריה...</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>מחק את ההיסטוריה</translation>
    </message>
    <message>
        <source>Do you want to clear the history?</source>
        <translation>האם ברצונך למחוק את ההיסטוריה?</translation>
    </message>
</context>
<context>
    <name>HistoryModel</name>
    <message>
        <source>Title</source>
        <translation>כותרת</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>כתובת</translation>
    </message>
</context>
<context>
    <name>HistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>מוקדם היום</translation>
    </message>
    <message numerus="yes">
        <source>%n item(s)</source>
        <translation>
            <numerusform>פריט אחד</numerusform>
            <numerusform>%n פריטים</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>JavaScriptAroraObject</name>
    <message>
        <source>Welcome to Arora!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arora Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search results provided by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Arora</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguageManager</name>
    <message>
        <source>Choose language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No translation files are installed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;הכנס את שם המשתמש והססמה עבור &quot;%1&quot; באתר %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Connect to proxy &quot;%1&quot; using:&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;מתחבר לשרת מתווך &quot;%1&quot; באמצעות:&lt;qt&gt;</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors?</source>
        <translation type="obsolete">שגיאות SSL:&lt;div dir=&quot;ltr&quot;&gt;￼%1￼
￼%2￼
&lt;/div&gt;
האם ברצונך להתעלם מהשגיאות הללו?￼</translation>
    </message>
    <message>
        <source>Do you want to accept all these certificates?</source>
        <translation type="obsolete">האם ברצונך לקבל את האישורים הללו?</translation>
    </message>
    <message>
        <source> - SSL Errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Do you want to ignore these errors?&lt;/qt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Issuer: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not valid before: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Valid until: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alternate Names:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">שם</translation>
    </message>
</context>
<context>
    <name>OpenSearchDialog</name>
    <message>
        <source>Open File</source>
        <translation type="unfinished">פתח קובץ</translation>
    </message>
    <message>
        <source>OpenSearch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must have at least one search engine in here.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OpenSearch Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restore Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSearchEngineModel</name>
    <message>
        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSearchManager</name>
    <message>
        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>נדרש אימות</translation>
    </message>
    <message>
        <source>DUMMY ICON</source>
        <translation>DUMMY ICON</translation>
    </message>
    <message>
        <source>INTRO TEXT DUMMY</source>
        <translation>INTRO TEXT DUMMY</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>שם משתמש:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>ססמה:</translation>
    </message>
</context>
<context>
    <name>PlainTextEditSearch</name>
    <message>
        <source>Not Found</source>
        <translation type="unfinished">לא נמצא</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>אימות שאת מתווך</translation>
    </message>
    <message>
        <source>ICON</source>
        <translation type="obsolete">ICON</translation>
    </message>
    <message>
        <source>Connect to proxy</source>
        <translation>התחבר לשרת מתווך</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>שם משתמש:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>ססמה:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The file is not an XBEL version 1.0 file.</source>
        <translation>הקובץ הוא לא קובץ XBEL מגרסה 1.0.</translation>
    </message>
    <message>
        <source>Unknown title</source>
        <translation>כותרת לא ידועה</translation>
    </message>
    <message>
        <source>The file is not an OpenSearch 1.1 file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RequestModel</name>
    <message>
        <source>Address</source>
        <translation type="obsolete">כתובת</translation>
    </message>
</context>
<context>
    <name>SearchBanner</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">מאת</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation type="obsolete">TextLabel</translation>
    </message>
    <message>
        <source>&lt;</source>
        <translation type="obsolete">&lt;</translation>
    </message>
    <message>
        <source>&gt;</source>
        <translation type="obsolete">&gt;</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>סיים</translation>
    </message>
    <message>
        <source>Highlight All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>חפש</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Preferences</source>
        <translation>הגדרות</translation>
    </message>
    <message>
        <source>General</source>
        <translation>כללי</translation>
    </message>
    <message>
        <source>On startup:</source>
        <translation>בהפעלה:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>הצג את דף הבית שלי</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>הצג דף ריק</translation>
    </message>
    <message>
        <source>Restore windows and tabs from last time</source>
        <translation>שחזר חלונות וכרטיסיות מהפעם הקודמת</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>דף הבית:</translation>
    </message>
    <message>
        <source>Set to current page</source>
        <translation>קבע לעמוד הנוכחי</translation>
    </message>
    <message>
        <source>Remove history items:</source>
        <translation>הסר פריטי היסטוריה:</translation>
    </message>
    <message>
        <source>After one day</source>
        <translation>אחרי יום אחד</translation>
    </message>
    <message>
        <source>After one week</source>
        <translation>אחרי שבוע אחד</translation>
    </message>
    <message>
        <source>After two weeks</source>
        <translation>אחרי שבועיים</translation>
    </message>
    <message>
        <source>After one month</source>
        <translation>אחרי חודש</translation>
    </message>
    <message>
        <source>After one year</source>
        <translation>אחרי שנה</translation>
    </message>
    <message>
        <source>Manually</source>
        <translation>ידנית</translation>
    </message>
    <message>
        <source>On application exit</source>
        <translation>בעת היציאה מהיישום</translation>
    </message>
    <message>
        <source>Open links from applications:</source>
        <translation>פתח קישורים מהיישומים:</translation>
    </message>
    <message>
        <source>In a tab in the current window</source>
        <translation type="obsolete">בכרטיסייה בחלון הנוכחי</translation>
    </message>
    <message>
        <source>In a new window</source>
        <translation>בחלון הנוכחי</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>הורדות</translation>
    </message>
    <message>
        <source>Ask for a destination each time</source>
        <translation>שאל היכן לשמור בכל פעם</translation>
    </message>
    <message>
        <source>Use this destination:</source>
        <translation>השתמש במקום הבא:</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>מראה</translation>
    </message>
    <message>
        <source>Standard font:</source>
        <translation>גופן ברירת־מחדל:</translation>
    </message>
    <message>
        <source>Times 16</source>
        <translation type="obsolete">Times 16</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>בחר...</translation>
    </message>
    <message>
        <source>Fixed-width font:</source>
        <translation>גופן קוחב קבוע:</translation>
    </message>
    <message>
        <source>Courier 13</source>
        <translation type="obsolete">Courier 13</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>פרטיות</translation>
    </message>
    <message>
        <source>Web Content</source>
        <translation>תוכן</translation>
    </message>
    <message>
        <source>Enable Plugins</source>
        <translation>אפשר תוספים</translation>
    </message>
    <message>
        <source>Enable Javascript</source>
        <translation>אפשר JavaScript</translation>
    </message>
    <message>
        <source>View Images</source>
        <translation>הצג תמונות</translation>
    </message>
    <message>
        <source>Cookies</source>
        <translation>עוגיות</translation>
    </message>
    <message>
        <source>Accept Cookies:</source>
        <translation>אפשר עוגיות:</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>תמיד</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>אך פעם</translation>
    </message>
    <message>
        <source>Only from sites you navigate to</source>
        <translation>רק מאתרים שאתה גולש בהם</translation>
    </message>
    <message>
        <source>Exceptions...</source>
        <translation>יוצאים מן הכלל...</translation>
    </message>
    <message>
        <source>Keep Cookies Until:</source>
        <translation>שמור עוגיות עד:</translation>
    </message>
    <message>
        <source>They expire</source>
        <translation>שהן פגות</translation>
    </message>
    <message>
        <source>I exit the application</source>
        <translation>אני יוצא מהיישום</translation>
    </message>
    <message>
        <source>At most 90 days</source>
        <translation>עד 90 יום</translation>
    </message>
    <message>
        <source>Cookies...</source>
        <translation>עוגיות...</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>כרטיסיות</translation>
    </message>
    <message>
        <source>Select tabs and windows as they are created</source>
        <translation>בחר כרטיסיות כשהן נוצרות</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs</source>
        <translation type="obsolete">וודא יציאה כאשר מספר כרטיסיות פתוחות</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>שרת מתווך</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>השתמש בשרת מתווך</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>סוג:</translation>
    </message>
    <message>
        <source>Socks5</source>
        <translation>Socks5</translation>
    </message>
    <message>
        <source>Http</source>
        <translation type="obsolete">Http</translation>
    </message>
    <message>
        <source>Host name:</source>
        <translation>שם משתמש:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>יציאה:</translation>
    </message>
    <message>
        <source>User Name:</source>
        <translation>שם משתמש:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>ססמה:</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>מתקדם</translation>
    </message>
    <message>
        <source>Style Sheet:</source>
        <translation>גיליון סגנון</translation>
    </message>
    <message>
        <source>Show only one close button instead of one for each tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preferred languages for viewing webpages in:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block Popup Windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opening links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Links that want to open in a new window:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In a new selected tab in the current window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In a new tab in the current window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In the current tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Http (Secure)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Http (Transparent)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use ClickToFlash on flash plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter Tracking Cookies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs or windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit the application when last tab is closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable network cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Restart required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SourceViewer</name>
    <message>
        <source>Loading...</source>
        <translation type="unfinished">טוען...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">ע&amp;ריכה</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation type="unfinished">&amp;חפש</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished">&amp;תצוגה</translation>
    </message>
    <message>
        <source>&amp;Wrap lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source of Page %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>Show Tab Bar</source>
        <translation>הצג כותרת כרטיסיות</translation>
    </message>
    <message>
        <source>Hide Tab Bar</source>
        <translation>הסתר כותרת כרטיסיות</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation type="obsolete">כרטיסייה &amp;חדשה</translation>
    </message>
    <message>
        <source>Duplicate Tab</source>
        <translation>שכפל כרטיסייה</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;סגור כרטיסייה</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>סגור כרטיסייות &amp;אחרות</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>טען כרטיסייה מחדש</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>רענן את כל הכרטיסיות</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>&amp;כרטיסייה חדשה</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;סגור כרטיסייה</translation>
    </message>
    <message>
        <source>Show Next Tab</source>
        <translation>הצג את הכרטיסייה הבאה</translation>
    </message>
    <message>
        <source>Show Previous Tab</source>
        <translation>הצג את הכרטסייה הקודמת</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>כרטיסיות שנסגרו לאחרונה</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>ללא שם</translation>
    </message>
    <message>
        <source>Do you really want to close this page?</source>
        <translation>האם באמת ברצונך לסגור את העמוד הזה?</translation>
    </message>
    <message>
        <source>You have modified this page and when closing it you would lose the modification.
Do you really want to close this page?
</source>
        <translation>אתה שינית את העמוד הזה וכאשר תסגור אותו אתה עללו לאבד מידע.
האם לסגור את העמוד בכל זאת?</translation>
    </message>
    <message>
        <source>Ctrl-]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl-[</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saved Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished">טוען...</translation>
    </message>
    <message>
        <source>Loading %1% (%2 %3)...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Finished loading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmark All Tabs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToolbarSearch</name>
    <message>
        <source>No Recent Searches</source>
        <translation>אין חיפושים אחרונים</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>חיפושים אחרונים</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation type="unfinished">אפס את החיפושים האחרונים</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebPage</name>
    <message>
        <source>Error loading page: %1</source>
        <translation>ארעה שגיאה באת הטעינה של העמוד: %1</translation>
    </message>
    <message>
        <source>When connecting to: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.arora-browser.org instead of &lt;b&gt;www&lt;/b&gt;.arora-browser.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If the address is correct, try checking the network connection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resending POST request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebView</name>
    <message>
        <source>Open in New &amp;Window</source>
        <translation>פתח ב&amp;חלון חדש</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>פתח ב&amp;כרטיסייה חדשה</translation>
    </message>
    <message>
        <source>Save Lin&amp;k</source>
        <translation>שמור &amp;קישור</translation>
    </message>
    <message>
        <source>&amp;Bookmark This Link</source>
        <translation>שים קישור ב&amp;סימניות</translation>
    </message>
    <message>
        <source>&amp;Copy Link Location</source>
        <translation>העתק &amp;מיקום הקישור</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Window</source>
        <translation>פתח &amp;תמונה בחלון חדש</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Tab</source>
        <translation>פתח תמונה ב&amp;כרטיסייה חדשה</translation>
    </message>
    <message>
        <source>&amp;Save Image</source>
        <translation>&amp;שמור תמונה</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>&amp;העתק תמונה</translation>
    </message>
    <message>
        <source>C&amp;opy Image Location</source>
        <translation>ה&amp;עתק מיקום התמונה</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>טוען...</translation>
    </message>
    <message>
        <source>Search with...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to the toolbar search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Method not supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 method is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose the desired search engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type in a name for the engine</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebViewSearch</name>
    <message>
        <source>Not Found</source>
        <translation>לא נמצא</translation>
    </message>
</context>
</TS>
